<?php

class CMA_Updater {

    private $api_results;
    private $tf_username;
    private $tf_purchasecode;
    private $checked;
    private $slug;
    private $plugin;
    private $error = false;
    private $update_check_delay = 48; // hours
    private $clear_cache_response;

    function __construct() {

        // REMOVES TRANSIENT - FOR DEBUGGING
        //set_site_transient( 'update_plugins', null );

        add_filter( "pre_set_site_transient_update_plugins", array( $this, "set_transient" ) );

        //add_filter( "plugins_api", array( $this, "set_plugin_info" ), 10, 3 );

        add_action( 'admin_init', array( $this, 'init' ), 9 );

        add_action( 'admin_notices', array( $this, 'username_purchase_code_error_notice' ) );

        //add_action( 'wp_ajax_cma_clear_updates_cache', array( $this, 'clear_updates_cache' ) );

        add_filter( "plugins_api", array( $this, "set_plugin_info" ), 10, 3 );

        // compiler hook on save for old and new opt_name
        add_filter( 'redux/options/pi_theme_options/compiler', array( $this, 'clear_updates_cache' ), 1, 3 );
        add_filter( 'redux/options/volcanno_options/compiler', array( $this, 'clear_updates_cache' ), 1, 3 );
    }

    function init() {
        $plugin = explode( "/", PICMA_BASE_NAME );

        $folder = $plugin[0];

        $this->plugin = PICMA_BASE_NAME;

        $this->slug = $folder;

        $this->get_themeforest_details();
    }

    public function get_plugin_version() {

        // Only do this once
        if ( !empty( $this->api_results ) ) {
            return;
        }

        if ( !empty( $this->tf_username ) && !empty( $this->tf_purchasecode ) ) {
            
            $username = strip_tags( $this->tf_username );
            $purchase_code = strip_tags( $this->tf_purchasecode );

            // API url
            $url = "http://pixel-industry.com/wp-json/volcanno/v1/plugin/content-maker/{$username}/{$purchase_code}";

            $response = wp_remote_get( $url );

            // Check for error
            if ( is_wp_error( $response ) || !isset( $response['body'] ) ) {
                $this->error = true;
            }

            $data = wp_remote_retrieve_body( $response );

            // Check for error
            if ( is_wp_error( $data ) ) {
                $this->error = true;
            }

            if ( !empty( $data ) ) {
                $data = @json_decode( $data );

                if ( is_wp_error( $data ) || isset( $data->code ) ) {
                    $this->error = true;
                } else {
                    $this->api_results = $data;
                }
            }

            // check if errors are returned and store flag into database
            if ( $this->error ) {
                update_option( 'cma_updater_error', 1 );
            } else {
                update_option( 'cma_updater_error', 0 );
            }
        }
    }

    // Push in plugin version information to display in the details lightbox
    public function set_plugin_info( $false, $action, $response ) {

        // If nothing is found, do nothing
        if ( empty( $response->slug ) || $response->slug != $this->slug ) {
            return false;
        }

        $info = get_option( 'cma_last_update_info' );

        if ( !empty( $info ) ) {
            $response->name = ucwords( str_replace( array( '-', '_' ), ' ', $response->slug ) );
            $response->version = $info['version'];
            $response->author = 'Pixel Industry';
            $response->homepage = 'www.pixel-industry.com';
            $response->download_link = $info['download'];

            // Create tabs in the lightbox
            $response->sections = array(
                'changelog' => trim( preg_replace( '/\s\s+/', ' </p> ', $info['changelog'] ) )
            );
        } else {
            $response->sections = array(
                'changelog' => 'Changelog not available'
            );
        }

        return $response;
    }

    /**
     * Display notice in case ThemeForest username of Purchase code are not correct
     */
    public function username_purchase_code_error_notice() {

        // get value from user meta
        $error = get_option( 'cma_updater_error' );

        // if notice wasn't dismissed, show it
        if ( $error == 1 ) {
            // notice class
            $class = "notice notice-error is-dismissible";

            // url where user will be redicted when clicks on link
            $page_url = esc_url( admin_url( 'admin.php?page=install-required-plugins' ) );

            // message text
            $message = sprintf( __( "Content Maker can't check for updates. Please verify ThemeForest username and Purchase code set in Theme options and recheck updates using refresh button in admin bar.", 'pi-cma' ), $page_url );

            // show message
            echo "<div class='{$class}'> <p>{$message}</p></div>";
        }
    }

    /**
     * Set transient where we will check if update for our plugin is avaible 
     * 
     * @param type $transient
     * @return object
     */
    public function set_transient( $transient ) {

        $do_update = false;

        $last_update_check = get_option( 'cma_last_update_check' );
        $update_check_seconds = $this->update_check_delay * 60 * 60; // seconds
        $next_update_check = $last_update_check + $update_check_seconds;

        // If we have checked the plugin data before, don't re-check
        if ( empty( $transient->checked ) || (!empty( $last_update_check ) && ($next_update_check < time())) ) {
            return $transient;
        }

        $this->get_plugin_version();

        $plugin_current_version = PICMA_VERSION;

        // Check the versions if we need to do an update
        if ( !empty( $this->api_results ) && !empty( $this->api_results->version ) ) {
            $do_update = version_compare( $this->api_results->version, $plugin_current_version );
        }

        // Update the transient to include our updated plugin data
        if ( $do_update == 1 ) {

            $package = $this->api_results->file_url;
            $version = $this->api_results->version;
            $changelog = $this->api_results->changelog;

            $obj = new stdClass();
            $obj->plugin = $this->plugin;
            $obj->slug = $this->slug;
            $obj->new_version = $version;
            $obj->url = "www.pixel-industry.com";
            $obj->package = $package;

            $transient->response[$obj->plugin] = $obj;

            // info that will be used when user click View version details
            $info = array(
                'version' => $version,
                'changelog' => $changelog,
                'download' => $package
            );

            update_option( 'cma_last_update_info', $info );
        }

        update_option( 'cma_last_update_check', time() );

        return $transient;
    }

    /**
     * Get ThemeForest username and purchase code from theme options
     */
    public function get_themeforest_details() {

        $username = strip_tags( cma_get_settings( 'tf_username' ) );
        $purchase_code = strip_tags( cma_get_settings( 'tf_purchasecode' ) );

        // check if credentials are available
        if ( !empty( $username ) && !empty( $purchase_code ) ) {
            $this->tf_username = $username;
            $this->tf_purchasecode = $purchase_code;
        }
    }

    /**
     * Clear updates cache in database
     */
    function clear_updates_cache( $options, $css, $changed_values ) {
        $clear_cache = '';

        // check if clear cache field is set
        if ( array_key_exists( 'cma_clear_updates_cache', $changed_values ) ) {

            global $volcanno_options, $pi_theme_options;

            // for new and old themes
            if ( !empty( $volcanno_options ) ) {
                $opt_name = 'volcanno_options';
                $clear_cache = $volcanno_options['cma_clear_updates_cache'];
            } else if ( !empty( $pi_theme_options ) ) {
                $opt_name = 'pi_theme_options';
                $clear_cache = $pi_theme_options['cma_clear_updates_cache'];
            }

            // check that field is checked
            if ( $clear_cache == '1' ) {

                // check current user permissions
                if ( current_user_can( 'manage_options' ) ) {

                    set_site_transient( 'update_plugins', null );
                    update_option( 'cma_last_update_check', '' );
                    update_option( 'cma_updater_error', 0 );

                    $this->clear_cache_response = __( 'Updates cache sucessfully cleared!', 'pi-cma' );

                    // clear checkbox value
                    if ( class_exists( 'Redux' ) ) {

                        Redux::setOption( $opt_name, 'cma_clear_updates_cache', '0' );
                    }
                } else {
                    $this->clear_cache_response = __( 'You do not have permission to clear the cache!', 'pi-cma' );
                }

                // show notice
                add_action( "redux/options/{$opt_name}/errors", array( $this, 'cache_clearing_admin_notice' ) );
            }
        }
    }

    /**
     * Show notice after clearing cache
     */
    function cache_clearing_admin_notice() {
        echo '<div class="redux-field-notice-cache notice-yellow"><strong><span></span> ' . $this->clear_cache_response . '</strong></div>';
    }

}

new CMA_Updater();
