<?php

/**
 * Setup Volcanno Framework
 */
function volcanno_setup_framework() {
    load_textdomain('volcanno', '');
}

add_action('after_setup_theme', 'volcanno_setup_framework', 12);

/**
 * Returns theme text domain
 * 
 * @global type $volcanno_theme_config
 * @return type string
 */
function volcanno_get_theme_textdomain() {
    global $volcanno_theme_config;

    // If the global textdomain isn't set, define it. Plugin/theme authors may also define a custom textdomain.
    if (!isset($volcanno_theme_config['text_domain']) || empty($volcanno_theme_config['text_domain'])) {
        $theme = wp_get_theme(get_template());
        $textdomain = $theme->get('TextDomain') ? $theme->get('TextDomain') : get_template();
        $volcanno_theme_config['text_domain'] = sanitize_key(apply_filters('volcanno_theme_textdomain', $textdomain));
    }
    // Return the expected textdomain of the parent theme.
    return $volcanno_theme_config['text_domain'];
}

/**
 * Check if user is on device with Retina display
 * 
 * @global type $vlc_is_retina
 * @global type $volcanno_options
 */
function volcanno_is_retina_device_check() {
    global $vlc_is_retina, $volcanno_options;

    $theme_name_clean = sanitize_title(THEME_NAME);
    $cookie_name = $theme_name_clean . "_device_pixel_ratio";

    // verify that user is on device with retina display
    if (isset($_COOKIE[$cookie_name]) && $volcanno_options['retina'] == '1') {
        $vlc_is_retina = ( $_COOKIE[$cookie_name] >= 2 );
    }
}

add_action('init', 'volcanno_is_retina_device_check', 11);

/**
 * Check if user is on device and double the size of the images
 * 
 * @global type $vlc_is_retina
 * @param type $params
 * @return type array
 */
function volcanno_retina_filter_image_size($params) {
    global $vlc_is_retina;

    if ($vlc_is_retina) {
        $params = array();

        if (isset($params['width'])) {
            $width = $params['width'];

            $params['width'] = $width * 2;
        }

        if (isset($params['height'])) {
            $height = $params['height'];

            $params['height'] = $height * 2;
        }
    }

    return $params;
}

add_filter('cma_element_image_dimensions', 'volcanno_retina_filter_image_size', 10, 2);
add_filter('volcanno_cpt_image_dimensions', 'volcanno_retina_filter_image_size');

if (!function_exists('volcanno_verify_audio_post_format_files')) {

    /**
     * Verify audio file type
     * 
     * @param type $audio_string
     * @return type array
     */
    function volcanno_verify_audio_post_format_files($audio_string) {
        $audio_urls = preg_split('/\r\n|[\r\n]/', $audio_string[0]);
        $allowed_formats = array('m4a', 'webma', 'oga', 'fla', 'wav', 'ogg');
        $valid_urls = array();
        foreach ($audio_urls as $url) {
            $audio_format = substr($url, strrpos($url, '.') + 1);
            if (in_array($audio_format, $allowed_formats)) {
                if ($audio_format == 'ogg')
                    $audio_format = 'oga';
                $valid_urls[$audio_format] = esc_url_raw($url);
            }
        }
        return $valid_urls;
    }

}
add_filter('volcanno_verify_post_audio', 'volcanno_verify_audio_post_format_files');

/**
 * Check if all required plugins are loaded for Portfolio and Gallery templates
 * 
 * @global string $vlc_page_title
 * @global type $volcanno_theme_config
 */
function volcanno_portofolio_gallery_required_plugins_loaded() {
    global $vlc_page_title, $volcanno_theme_config;

    if (!VOLCANNO_CPTS || !RWMB_META_BOX) {

        $vlc_page_title = 'Plugin activation required!';

        // include page title if portfolio/gallery single is loaded
        if (is_singular('pi_portfolio') || is_singular('pi_gallery')) {
            if (file_exist(VOLCANNO_THEME_DIR . "/page-title.php")) {
                get_template_part('page', 'title');
            } else {
                get_template_part('section', 'title');
            }
        }
        ?>
        <section class="page-content">
            <!-- container start -->
            <div class="container">
                <!-- .row start -->
                <div class="row">
                    <div class="col-md-12">
                        <?php
                        echo wp_kses(__('Please activate <strong>Custom post types</strong> and <strong>MetaBox</strong> plugins.', 'volcanno'), $volcanno_theme_config['allowed_html_tags']);
                        ?>
                    </div>
                </div><!-- .row end -->
            </div><!-- .container end -->
        </section>

        <?php
        // footer
        get_footer();

        exit;
    }
}

// hooks on CPT pages before items are rendered
add_action('volcanno_pre_cpt_items_render', 'volcanno_portofolio_gallery_required_plugins_loaded');
