<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Locations_Map")) {

    class CMA_Shortcodes_Locations_Map extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Locations Map', 'trucking');
            $settings['description'] = esc_html__('Creates Google Map with multiple locations of your choice.', 'trucking');
            $settings['shortcode'] = 'cma_locations_map';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function enqueue_scripts() {
            /* Scripts */
        }

        function shortcode_html($atts = array(), $content = null) {
            $style = '';
            $custom_markers = '';
            $html = '';
            $sorted_markers = array();

            extract(shortcode_atts(array(
                'type' => 'roadmap',
                'latitude' => "40.74843",
                'longitude' => '-73.985655',
                'zoom' => '13',
                'ui' => '1',
                'scroll' => '1',
                'contrast' => 'default',
                'height' => '',
                'markers' => '',
                'api_key' => ''
                            ), (array) $atts, 'cma_locations_map'));
            
            // get API key
            $api_key = trim($api_key);            
            $maps_api_url = "//maps.googleapis.com/maps/api/js?key=" . $api_key;
            
            /* Google Maps script */
            wp_enqueue_script( 'cma-scripts-googlemaps-api', $maps_api_url, array( 'jquery' ), '1.0', TRUE );            
            /* Script for Google Maps */
            wp_enqueue_script( 'cma-scripts-locations-map', CMA_CONTENT_URL . 'locations_map/js/locations_map.js', array( 'jquery', 'cma-scripts-googlemaps-api' ), '1.0', TRUE );     

            // output config object
            wp_localize_script('cma-scripts-locations-map', 'LocationsMap', array(
                'theme_url' => TEMPLATEURL
            ));
            
            if (!empty($height)) {
                $style = "style='height: {$height}px;'";
            }

            if (!empty($markers)) {
                foreach ($markers as $index => $marker) {
                    $sorted_markers[$index][] = strip_tags($marker['text']);
                    $sorted_markers[$index][] = strip_tags($marker['marker_latitude']);
                    $sorted_markers[$index][] = strip_tags($marker['marker_longitude']);                   
                    $sorted_markers[$index][] = $index;
                    
                    if (!empty($marker['icon'])) {
                        $image = wp_get_attachment_image_src(trim($marker['icon'], ','), 'full');
                        $sorted_markers[$index][] = esc_url($image[0]);
                    }
                }
                array_walk_recursive($sorted_markers, array($this, 'sanitize_array_values'));
                $sorted_markers = htmlspecialchars(json_encode($sorted_markers), ENT_QUOTES, 'UTF-8');
                $custom_markers = " data-markers='{$sorted_markers}'";
            }

            $html .= "<div class='locations-map' data-type='{$type}' data-long='{$longitude}' data-lat='{$latitude}' data-zoom='{$zoom}' data-default-ui='{$ui}' data-scroll-wheel='{$scroll}' data-contrast='{$contrast}' {$custom_markers} {$style}></div>";

            return $html;
        }

        function sanitize_array_values(&$item) {
            $item = strip_tags($item);

            return $item;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'trucking'),
                    'description' => esc_html__('Select Map type.', 'trucking'),
                    'options' => array(
                        'roadmap' => 'Road Map',
                        'terrain' => 'Terrain',
                        'satellite' => 'Satellite'
                    ),
                    'default' => 'roadmap'
                ),
                'latitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Map center Latitude', 'trucking'),
                    'description' => esc_html__('Latitude of center of the map.', 'trucking'),
                    'placeholder' => '46.305746'
                ),
                'longitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Map center Longitude', 'trucking'),
                    'description' => esc_html__('Longitude of center of the map.', 'trucking'),
                    'placeholder' => '16.336607'
                ),
                'zoom' => array(
                    'type' => 'number',
                    'title' => esc_html__('Zoom', 'trucking'),
                    'description' => esc_html__('Zoom parameter.', 'trucking'),
                    'default' => '13'
                ),
                'ui' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('User Interface', 'trucking'),
                    'description' => esc_html__('User Interface disable/enable.', 'trucking'),
                    'default' => '1'
                ),
                'scroll' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Zoom scrolling', 'trucking'),
                    'description' => esc_html__('Disable zoom when scrolling over map.', 'trucking'),
                    'default' => '0'
                ),
                'contrast' => array(
                    'type' => 'select',
                    'title' => esc_html__('Contrast', 'trucking'),
                    'description' => esc_html__('Change map appearance.', 'trucking'),
                    'options' => array(
                        'default' => 'Default',
                        'saturated' => 'Saturated',
                        'grayscale' => 'Grayscale',
                    ),
                    'default' => 'default'
                ),
                'height' => array(
                    'type' => 'number',
                    'title' => esc_html__('Height', 'trucking'),
                    'description' => esc_html__('Enter custom map height (default 500px).', 'trucking'),
                    'placeholder' => '500'
                ),
                'api_key' => array(
                    'type' => 'text',
                    'title' => esc_html__('API key', 'trucking'),
                    'description' => esc_html__('Enter your Google Maps API key. Guide can be found in Documentation.', 'trucking'),
                    'placeholder' => '',
                ),
                'markers' => array(
                    'type' => 'group',
                    'title' => esc_html__('Markers', 'trucking'),
                    'options' => array(
                        'text' => array(
                            'type' => 'text',
                            'title' => esc_html__('Text', 'trucking'),
                            'description' => esc_html__('Enter point description - appears as tooltip.', 'trucking'),
                            'placeholder' => 'Point/Marker description.'
                        ),
                        'marker_latitude' => array(
                            'type' => 'text',
                            'title' => esc_html__('Marker Latitude', 'trucking'),
                            'description' => esc_html__('Custom marker latitude.', 'trucking'),
                            'placeholder' => '46.305746'
                        ),
                        'marker_longitude' => array(
                            'type' => 'text',
                            'title' => esc_html__('Marker Longitude', 'trucking'),
                            'description' => esc_html__('Custom marker longitude.', 'trucking'),
                            'placeholder' => '16.336607'
                        ),
                        'icon' => array(
                            'type' => 'image',
                            'title' => esc_html__('Icon', 'trucking'),
                            'description' => esc_html__('If custom icon is not set, default one will be used.', 'trucking')
                        ),
                    )
                ),
            );
        }

    }

}
?>
