<?php

/**
 * Register menu for fetching Icon Fonts
 */
function volcanno_register_icon_font_fetching_menu() {
    global $volcanno_theme_config;

    // add menu for Icons fonts
    add_submenu_page( 'volcanno_options', 'Icon Fonts', 'Icon Fonts', 'manage_options', 'volcanno_icon_fonts', 'volcanno_render_icon_fonts_page', '', 82 );

    foreach ( $volcanno_theme_config['icon_fonts'] as $name => $files ) {
        $icons = array();

        // concencate name of function that return font from db
        $func_name = 'volcanno_' . $name . '_classes';

        if ( function_exists( $func_name ) ) {
            $icons = call_user_func( $func_name );


            // check if icons are empty
            if ( empty( $icons ) || count( $icons ) < 2 ) {
                $access_type = get_filesystem_method();

                // if we have dirrect access trying parsing icons
                // otherwise display the notice
                if ( $access_type === 'direct' ) {
                    volcanno_icon_font_css( $access_type, null, true );
                } else {
                    //  don't have direct write access. Prompt user with our notice
                    add_action( 'admin_notices', 'volcanno_file_reading_notice' );
                }

                break;
            }
        }
    }
}

add_action( 'admin_menu', 'volcanno_register_icon_font_fetching_menu' );

/**
 * Display notice for parsing Icon Font
 */
function volcanno_file_reading_notice() {
    global $volcanno_theme_config;

    // notice class
    $class = "updated";

    // url where user will be redicted when clicks on link
    $page_url = esc_url( admin_url( 'admin.php?page=volcanno_icon_fonts' ) );

    // message text
    $message = wp_kses( sprintf( __( "Theme requires access to File System to load Icon Fonts. Please <a href='%s'>click here</a> to enter your credentials.", 'volcanno' ), $page_url ), $volcanno_theme_config['allowed_html_tags'] );

    // show message
    echo "<div class='{$class}'> <p>{$message}</p></div>";
}

/**
 * Render page for parsing icons fonts
 */
function volcanno_render_icon_fonts_page() {
    global $volcanno_theme_config;

    // check what kind of access to filesystem we have
    $access_type = get_filesystem_method();

    echo '<div class="volcanno-icon-fonts">
            <h2>Load icon fonts</h2>';

    // check if user clicked on button otherwise show form
    if ( empty( $_POST ) ) {
        ?>        
        <form action="" method="post">
            <?php wp_nonce_field( 'volcanno-icon-fonts' ); ?>
            <p>In case you updated Icons Fonts (e.g. Font Awesome) please re-load them again by clicking on button below.</p>
            <input name="save" type="submit" value="Load icons fonts" />
            <input type="hidden" name="autoload" value="<?php echo '0' ?>"/>
        </form>

        <?php
    } else {
        // verify referer
        check_admin_referer( 'volcanno-icon-fonts' );

        // pass the data in request
        $form_fields = array( 'save', '_wpnonce', 'autoload' );

        // check if this is autoload or user requested loading
        if ( isset( $_POST['autoload'] ) ) {
            $autoload = $_POST['autoload'];
        } else {
            $autoload = true;
        }

        volcanno_icon_font_css( $access_type, $form_fields, $autoload );
    }

    echo '</div>';
}

/**
 * Load Font Awesome.
 * 
 * @global type $wp_filesystem
 * @global type $volcanno_theme_config
 * @return boolean
 */
function volcanno_icon_font_css( $access_type, $form_fields, $auto_load ) {
    global $volcanno_theme_config;

    // do our file manipulations below
    $fonts = array();

    // url where user will be redicted when clicks on link
    $page_url = esc_url( admin_url( 'admin.php?page=volcanno_icon_fonts' ) );

    // go through all available fonts
    foreach ( $volcanno_theme_config['icon_fonts'] as $name => $files ) {
        $fonts[$name] = isset( $files['local'] ) ? $files['local'] : '';
    }

    // check what kind of access we have
    if ( $access_type === 'direct' ) {

        // safely run request_filesystem_credentials() without any issues and don't need to worry about passing in a URL
        $creds = request_filesystem_credentials( site_url() . '/wp-admin/', '', false, false, array() );

        // initialize the API
        if ( !WP_Filesystem( $creds ) ) {
            // any problems and we exit
            return false;
        }

        global $wp_filesystem;

        // go through all fonts
        foreach ( $fonts as $font_name => $font_file_path ) {

            // check if file exists
            if ( !empty( $font_file_path ) ) {

                // check if file path is set
                if ( $wp_filesystem->exists( $font_file_path ) ) {

                    // fetch font file content
                    $css = $wp_filesystem->get_contents( $font_file_path );

                    // concencate function name
                    $func_name = 'volcanno_parse_' . $font_name . '_css';

                    // call parse function if it exists
                    if ( function_exists( $func_name ) ) {
                        call_user_func( $func_name, $css, $auto_load );
                    }
                }
            }
        }
    } else {

        $url = wp_nonce_url( "admin.php?page=volcanno_icon_fonts", "filesystem-nonce" );

        // ask for credentials
        if ( volcanno_connect_fs( $url, "", false, $form_fields ) ) {
            global $wp_filesystem;

            // go through all fonts
            foreach ( $fonts as $font_name => $font_file_path ) {

                // check if file path is set
                if ( !empty( $font_file_path ) ) {

                    // check if file exists
                    if ( $wp_filesystem->exists( $font_file_path ) ) {

                        // fetch font file content
                        $css = $wp_filesystem->get_contents( $font_file_path );
                    } else {
                        $css = volcanno_get_font_from_remote_location( $font_name );

                        if ( !$css ) {
                            // print error
                            print_r( "<div class='error'>Parsing " . $font_name . " failed!</div>" );
                            return false;
                        }
                    }

                    // concencate function name
                    $func_name = 'volcanno_parse_' . $font_name . '_css';

                    // call parse function if it exists
                    if ( function_exists( $func_name ) ) {
                        call_user_func( $func_name, $css, $auto_load );
                    }
                }
            }
        } else {
            return false;
        }
    }

    if ( !$auto_load ) {
        echo "<a class='volcanno-icon-fonts-return' href='" . $page_url . "'>" . esc_html__( 'Return', 'volcanno' ) . "</a>";
    }
}

/**
 * Gets icons font CSS file from remote location
 * 
 * @global type $volcanno_theme_config
 * @param type $font_name
 * @return boolean
 */
function volcanno_get_font_from_remote_location( $font_name ) {
    global $volcanno_theme_config;

    // go through all available fonts
    foreach ( $volcanno_theme_config['icon_fonts'] as $name => $files ) {
        $fonts[$name] = isset( $files['remote'] ) ? $files['remote'] : '';
    }

    if ( isset( $fonts[$font_name] ) && !empty( $fonts[$font_name] ) ) {
        $request = wp_remote_get( $fonts[$font_name], array( 'sslverify' => false ) );

        if ( !is_wp_error( $request ) || wp_remote_retrieve_response_code( $request ) === 200 ) {
            $data = wp_remote_retrieve_body( $request );
            return $data;
        } else {
            return false;
        }
    }
}

/**
 * Parse Font Awesome string and extract classes.
 * 
 * @param string $css String with all classes
 * @param string $auto_load Is request autoloading or user requested
 */
function volcanno_parse_font_awesome_css( $css, $auto_load ) {
    // parse the content and store in array
    if ( !empty( $css ) ) {
        $pattern = '/\.(fa-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"(.+)";\s+}/';

        preg_match_all( $pattern, $css, $matches, PREG_SET_ORDER );

        $icons = array();
        foreach ( $matches as $match ) {
            $icons[$match[1]] = ucfirst( str_ireplace( array( 'fa-', '-' ), array( '', ' ' ), $match[1] ) );
        }
        $page_url = esc_url( admin_url( 'admin.php?page=volcanno_icon_fonts' ) );

        // don't show the message if icons are auto loading
        if ( !$auto_load ) {
            echo "<div class='updated'>" . esc_html__( 'Parsing Font Awesome successful.', 'volcanno' ) . "</div>";
        }
    } else {
        $icons = array( 'Icons not parsed' );

        if ( !$auto_load ) {
            echo "<div class='error'>" . esc_html__( 'Error while parsing Font Awesome, please try again!', 'volcanno' ) . "</div>";
        }
    }

    update_option( 'volcanno_font_awesome_list', $icons );
}

/**
 * Font Awesome classes
 *
 * @return array
 */
function volcanno_font_awesome_classes() {

    // get icon list from database
    $icons = get_option( 'volcanno_font_awesome_list' );
    $icons = apply_filters( 'volcanno_font_awesome_list', $icons );

    // reset array - for testing
    //$icons = null;

    return $icons;
}

/**
 * Parse Linecons string and extract classes.
 * 
 * @param string $css String with all classes
 * @param string $auto_load Is request autoloading or user requested
 */
function volcanno_parse_linecons_css( $css, $auto_load ) {

    // parse the content and store in array
    if ( !empty( $css ) ) {
        $pattern = '/\.(linecons-(?:\w+(?:-)?)+):before\s+{\s*content:\s*"(.+)";\s+}/';

        preg_match_all( $pattern, $css, $matches, PREG_SET_ORDER );

        $icons = array();
        foreach ( $matches as $match ) {
            $icons[$match[1]] = $match[1];
        }

        $page_url = esc_url( admin_url( 'admin.php?page=volcanno_icon_fonts' ) );

        // don't show the message if icons are auto loading
        if ( !$auto_load ) {
            echo "<div class='updated'>" . esc_html__( 'Parsing Linecons successful.', 'volcanno' ) . "</div>";
        }
    } else {
        $icons = array( 'Icons not parsed' );

        if ( !$auto_load ) {
            echo "<div class='error'>" . esc_html__( 'Error while parsing Linecons, please try again!', 'volcanno' ) . "</div>";
        }
    }

    update_option( 'volcanno_linecons_list', $icons );
}

/**
 * Linecons classes
 *
 * @return array
 */
function volcanno_linecons_classes() {

    // get icon list from database
    $icons = get_option( 'volcanno_linecons_list' );
    $icons = apply_filters( 'volcanno_linecons_list', $icons );

    // reset array - for testing
    //$icons = null;

    return $icons;
}

/**
 * Returns array of Pixons clases
 * 
 * @return array
 */
function volcanno_get_pixons_names() {
    $prefix = 'pixons-';

    $icons = array(
        $prefix . 'amazon' => $prefix . 'amazon',
        $prefix . 'android' => $prefix . 'android',
        $prefix . 'aol' => $prefix . 'aol',
        $prefix . 'apple' => $prefix . 'apple',
        $prefix . 'behance' => $prefix . 'behance',
        $prefix . 'bing' => $prefix . 'bing',
        $prefix . 'blogger' => $prefix . 'blogger',
        $prefix . 'buzz' => $prefix . 'buzz',
        $prefix . 'delicious' => $prefix . 'delicious',
        $prefix . 'deviantart' => $prefix . 'deviantart',
        $prefix . 'digg' => $prefix . 'digg',
        $prefix . 'dribbble' => $prefix . 'dribbble',
        $prefix . 'dropbox' => $prefix . 'dropbox',
        $prefix . 'drupal' => $prefix . 'drupal',
        $prefix . 'ember' => $prefix . 'ember',
        $prefix . 'envato' => $prefix . 'envato',
        $prefix . 'evernote' => $prefix . 'evernote',
        $prefix . 'facebook-1' => $prefix . 'facebook-1',
        $prefix . 'facebook-2' => $prefix . 'facebook-2',
        $prefix . 'feedburner' => $prefix . 'feedburner',
        $prefix . 'forrst' => $prefix . 'forrst',
        $prefix . 'flickr' => $prefix . 'flickr',
        $prefix . 'foursquare' => $prefix . 'foursquare',
        $prefix . 'github' => $prefix . 'github',
        $prefix . 'github-2' => $prefix . 'github-2',
        $prefix . 'google_plus' => $prefix . 'google_plus',
        $prefix . 'grooveshark' => $prefix . 'grooveshark',
        $prefix . 'html5' => $prefix . 'html5',
        $prefix . 'instagram' => $prefix . 'instagram',
        $prefix . 'lastfm' => $prefix . 'lastfm',
        $prefix . 'linkedin' => $prefix . 'linkedin',
        $prefix . 'metacafe' => $prefix . 'metacafe',
        $prefix . 'mixx' => $prefix . 'mixx',
        $prefix . 'myspace' => $prefix . 'myspace',
        $prefix . 'newsvine' => $prefix . 'newsvine',
        $prefix . 'paypal' => $prefix . 'paypal',
        $prefix . 'picasa' => $prefix . 'picasa',
        $prefix . 'pinterest' => $prefix . 'pinterest',
        $prefix . 'plixi' => $prefix . 'plixi',
        $prefix . 'plurk' => $prefix . 'plurk',
        $prefix . 'posterous' => $prefix . 'posterous',
        $prefix . 'reddit' => $prefix . 'reddit',
        $prefix . 'rss' => $prefix . 'rss',
        $prefix . 'sharethis' => $prefix . 'sharethis',
        $prefix . 'skype' => $prefix . 'skype',
        $prefix . 'soundcloud' => $prefix . 'soundcloud',
        $prefix . 'stumbleupon' => $prefix . 'stumbleupon',
        $prefix . 'technorati' => $prefix . 'technorati',
        $prefix . 'tumblr' => $prefix . 'tumblr',
        $prefix . 'tux' => $prefix . 'tux',
        $prefix . 'twitter-1' => $prefix . 'twitter-1',
        $prefix . 'twitter-2' => $prefix . 'twitter-2',
        $prefix . 'vimeo' => $prefix . 'vimeo',
        $prefix . 'wordpress' => $prefix . 'wordpress',
        $prefix . 'xing' => $prefix . 'xing',
        $prefix . 'yahoo' => $prefix . 'yahoo',
        $prefix . 'yelp' => $prefix . 'yelp',
        $prefix . 'youtube' => $prefix . 'youtube',
        $prefix . 'zerply' => $prefix . 'zerply',
        $prefix . 'zootool' => $prefix . 'zootool'
    );
    ksort( $icons );

    return $icons;
}
?>
