<?php
/* -----------------------------------------------------------------------------------

  Plugin Name: Contact Info Widget
  Plugin URI: http://www.pixel-industry.com
  Description: A widget that displays contact information.
  Version: 1.0
  Author: Pixel Industry
  Author URI: http://www.pixel-industry.com

  ----------------------------------------------------------------------------------- */


// Add function to widgets_init that'll load our widget
add_action( 'widgets_init', 'volcanno_register_contact_info' );

// Register widget
function volcanno_register_contact_info() {
    register_widget( 'Volcanno_Contact_Info' );
}

// Widget class
class Volcanno_Contact_Info extends WP_Widget {
    /* ----------------------------------------------------------------------------------- */
    /* 	Widget Setup
      /*----------------------------------------------------------------------------------- */

    function __construct() {

        // Widget settings
        $widget_options = array(
            'classname' => 'contact-info',
            'description' => esc_html__( 'A widget that displays contact information.', 'volcanno' )
        );


        // Create the widget
        parent::__construct( 'Volcanno_Contact_Info', esc_html__( 'Contact Info', 'volcanno' ), $widget_options );
    }

    /* ----------------------------------------------------------------------------------- */
    /* 	Display Widget
      /*----------------------------------------------------------------------------------- */

    function widget( $args, $instance ) {
        global $volcanno_theme_config;
        $address_string_html = '';
        $phone_string_html = '';
        $email_string_html = '';
        $icon = '';

        extract( $args );

        // Our variables from the widget settings
        $title = apply_filters( 'widget_title', $instance['title'] );

        // Before widget (defined by theme functions file)
        echo $before_widget;

        // Display the widget title if one was input
        if ( $title )
            echo $before_title . $title . $after_title;

        $address_string = !empty( $instance['address_string'] ) ? $instance['address_string'] : '';
        $phone_string = !empty( $instance['phone_string'] ) ? $instance['phone_string'] : '';
        $email_string = !empty( $instance['email_string'] ) ? $instance['email_string'] : '';

        // HTML allowed
        echo $instance['before'];

        echo "<address><ul class='contact-info-list'>";

        if ( !empty( $instance['address'] ) ) {
            $icon_html = '';

            $address = wp_kses( $instance['address'], $volcanno_theme_config['allowed_html_tags'] );

            if ( !empty( $address_string ) ) {
                $address_string_html = "<span class='strong'>{$address_string} </span>";
            }

            if ( !empty( $instance['address_icon'] ) ) {
                $icon = $instance['address_icon'];
                $icon_html = "<i class='fa {$icon}'></i>";
            }

            echo "<li>                        
                    {$icon_html}
                    {$address_string_html}
                    {$address}                        
                  </li>";
        }

        do_action( 'wci_print_home' );

        if ( !empty( $instance['phone'] ) ) {
            $phone_html = '';

            if ( !empty( $phone_string ) ) {
                $phone_string_html = "<span class='strong'>{$phone_string} </span>";
            }

            if ( !empty( $instance['phone_icon'] ) ) {
                $icon = $instance['phone_icon'];
                $icon_html = "<i class='fa {$icon}'></i>";
            }

            $phone = strip_tags( $instance['phone'] );
            $phone = explode( ',', $phone );

            foreach ( $phone as $key => $single ) {
                if ( $key > 0 ) {
                    $phone_html .= '<br>' . $single;
                } else
                    $phone_html .= $single;
            }

            echo "<li>                        
                    {$icon_html}
                    {$phone_string_html}
                    {$phone_html}                        
                  </li>";
        }

        do_action( 'wci_print_phone' );

        if ( !empty( $instance['email'] ) ) {

            if ( !empty( $email_string ) ) {
                $email_string_html = "<span class='strong'>{$email_string} </span>";
            }

            if ( !empty( $instance['email_icon'] ) ) {
                $icon = $instance['email_icon'];
                $icon_html = "<i class='fa {$icon}'></i>";
            }
            
            $email = explode( ',', $instance['email'] );

            $email_html = '';

            foreach ( $email as $key => $single ) {

                $single = preg_replace( '/\s+/', '', $single );
                $single = sanitize_email( $single );
                $email_html .= '<a href="mailto:' . $single . '"><span class="mail_span">' . $single . '</span></a>';
            }

            echo "<li>                       
                        {$icon_html}
                        {$email_string_html}
                        {$email_html}                        
                    </li>";
        }

        do_action( 'wci_print_email' );

        echo "</ul></address>";

        // HTML allowed
        echo $instance['after'];

        // After widget (defined by theme functions file)
        echo $after_widget;
    }

    /* ----------------------------------------------------------------------------------- */
    /* 	Update Widget
      /*----------------------------------------------------------------------------------- */

    function update( $new_instance, $old_instance ) {
        global $volcanno_theme_config;

        $instance = $old_instance;

        // Strip tags to remove HTML (important for text inputs)
        $instance['title'] = strip_tags( $new_instance['title'] );
        $instance['before'] = $new_instance['before'];
        $instance['address_string'] = strip_tags( $new_instance['address_string'] );
        $instance['address_icon'] = strip_tags( $new_instance['address_icon'] );
        $instance['address'] = wp_kses( $new_instance['address'], $volcanno_theme_config['allowed_html_tags'] );
        $instance['phone_string'] = strip_tags( $new_instance['phone_string'] );
        $instance['phone_icon'] = strip_tags( $new_instance['phone_icon'] );
        $instance['phone'] = strip_tags( $new_instance['phone'] );
        $instance['email_string'] = strip_tags( $new_instance['email_string'] );
        $instance['email_icon'] = strip_tags( $new_instance['email_icon'] );
        $instance['email'] = strip_tags( $new_instance['email'] );
        $instance['after'] = $new_instance['after'];

        // No need to strip tags

        return $instance;
    }

    /* ----------------------------------------------------------------------------------- */
    /* 	Widget Settings (Displays the widget settings controls on the widget panel)
      /*----------------------------------------------------------------------------------- */

    function form( $instance ) {
        global $volcanno_theme_config;

        // Set up some default widget settings
        $defaults = array(
            'title' => 'Contact Info',
            'before' => '',
            'address_string' => 'Address:',
            'address_icon' => 'fa-home',
            'address' => '',
            'phone_string' => 'Phone:',
            'phone_icon' => 'fa-phone',
            'phone' => '',
            'email_string' => 'E-Mail:',
            'email_icon' => 'fa-envelope-o',
            'email' => '',
            'after' => '',
        );

        $instance = wp_parse_args( ( array ) $instance, $defaults );
        ?>

        <!-- Widget Title: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" value="<?php echo sanitize_text_field( $instance['title'] ); ?>" />
        </p>

        <!-- Before: Textarea -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'before' ) ); ?>"><?php esc_html_e( 'Before:', 'volcanno' ) ?></label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'before' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'before' ) ); ?>"><?php echo esc_textarea( $instance['before'] ); ?></textarea>
        </p>

        <!-- Address String: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'address_string' ) ); ?>"><?php esc_html_e( 'Address Text:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'address_string' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'address_string' ) ); ?>" value="<?php echo sanitize_text_field( $instance['address_string'] ); ?>" />
        </p>

        <!-- Address Icon: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'address_icon' ) ); ?>"><?php _e( 'Address Icon (<a href="https://fortawesome.github.io/Font-Awesome/cheatsheet/" target="_BLANK">Font Awesome</a>):', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'address_icon' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'address_icon' ) ); ?>" value="<?php echo sanitize_text_field( $instance['address_icon'] ); ?>" />
        </p>


        <!-- Address: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'address' ) ); ?>"><?php esc_html_e( 'Address:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'address' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'address' ) ); ?>" value="<?php echo wp_kses( $instance['address'], $volcanno_theme_config['allowed_html_tags'] ); ?>" />
        </p>

        <!-- Phone String: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'phone_string' ) ); ?>"><?php esc_html_e( 'Phone Text:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone_string' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone_string' ) ); ?>" value="<?php echo sanitize_text_field( $instance['phone_string'] ); ?>" />
        </p>

        <!-- Phone Icon: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'phone_icon' ) ); ?>"><?php _e( 'Phone Icon (<a href="https://fortawesome.github.io/Font-Awesome/cheatsheet/" target="_BLANK">Font Awesome</a>):', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone_icon' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone_icon' ) ); ?>" value="<?php echo sanitize_text_field( $instance['phone_icon'] ); ?>" />
        </p>

        <!-- Phone: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>"><?php esc_html_e( 'Phone:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone' ) ); ?>" value="<?php echo sanitize_text_field( $instance['phone'] ); ?>" />
        </p>

        <!-- E-Mail string: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'email_string' ) ); ?>"><?php esc_html_e( 'E-Mail Text:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email_string' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email_string' ) ); ?>" value="<?php echo sanitize_text_field( $instance['email_string'] ); ?>" />
        </p>

        <!-- E-Mail icon: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'email_icon' ) ); ?>"><?php _e( 'E-Mail Icon (<a href="https://fortawesome.github.io/Font-Awesome/cheatsheet/" target="_BLANK">Font Awesome</a>):', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email_icon' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email_icon' ) ); ?>" value="<?php echo sanitize_text_field( $instance['email_icon'] ); ?>" />
        </p>

        <!-- E-Mail: Text Input -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>"><?php esc_html_e( 'E-Mail:', 'volcanno' ) ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'email' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'email' ) ); ?>" value="<?php echo sanitize_email( $instance['email'] ); ?>" />
        </p>

        <!-- After: Textarea -->
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'after' ) ); ?>"><?php esc_html_e( 'After:', 'volcanno' ) ?></label>
            <textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'after' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'after' ) ); ?>"><?php echo esc_textarea( $instance['after'] ); ?></textarea>
        </p>

        <?php
    }

}
?>