<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Buttons")) {

    class CMA_Shortcodes_Buttons extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Buttons', 'trucking');
            $settings['description'] = esc_html__('Buttons of multiple types, sizes and colors.', 'trucking');
            $settings['shortcode'] = 'cma_buttons';
            $settings['nested'] = false;
            $settings['selected_option'] = 'text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            $btn_color = '';
            $btn_target = '';
            $classes = 'btn';

            extract(shortcode_atts(array(
                'size' => 'medium',
                'position' => 'float-right',
                'icon' => '',
                'color_type' => 'predefined',
                'predefined_color' => 'blue',
                'custom_color' => '#ddd',
                'text' => 'Button',
                'link' => '',
                'target' => '',
                            ), $atts, 'cma_buttons'));

            // button icon
            if (!empty($icon)) {
                $icon = "<i class='{$icon}'></i>";
                $classes .= ' icon-animated';
            }

            // open in new window
            if ($target == '1') {
                $btn_target = 'target="_BLANK"';
            }

            // button color
            if ($color_type == 'custom') {
                $btn_color = "style='background: {$custom_color};'";
                $classes .= ' custom-color';
            } else {
                $classes .= " " . $predefined_color;
            }

            // button size
            $classes .= ' btn-' . esc_html($size);

            // button position
            $classes .= ' ' . $position;

            $text = esc_html($text);
            
            $link = esc_url($link);

            $html = "<a href='{$link}' class='{$classes}' {$btn_target} {$btn_color}><span>{$icon} {$text}</span></a><div class='clearfix'></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'size' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Size', 'trucking'),
                    'description' => esc_html__('Select button size', 'trucking'),
                    'options' => array(
                        'small' => esc_html__('Small', 'trucking'),
                        'medium' => esc_html__('Medium', 'trucking'),
                        'big' => esc_html__('Big', 'trucking'),
                    ),
                    'default' => 'medium'
                ),
                'icon' => array(
                    'type' => 'icon_picker',
                    'title' => esc_html__('Icon', 'trucking'),
                    'description' => esc_html__('Add button icon.', 'trucking')
                ),
                'color_type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Color type', 'trucking'),
                    'description' => esc_html__('Select between predefined color or custom color.', 'trucking'),
                    'options' => array(
                        'predefined' => esc_html__('Predefined', 'trucking'),
                        'custom' => esc_html__('Custom', 'trucking')
                    ),
                    'default' => 'predefined'
                ),
                'predefined_color' => array(
                    'type' => 'select',
                    'title' => esc_html__('Predefined color', 'trucking'),
                    'description' => esc_html__('Select between predefined button colors.', 'trucking'),
                    'options' => array(
                        'blue' => esc_html__('Blue', 'trucking'),
                        'yellow' => esc_html__('Yellow', 'trucking')
                    ),
                    'default' => 'blue',
                    'condition' => array('color_type', '=', 'predefined')
                ),
                'custom_color' => array(
                    'type' => 'color_picker',
                    'title' => esc_html__('Color', 'trucking'),
                    'description' => esc_html__('Select button color from color wheel.', 'trucking'),
                    'default' => '',
                    'condition' => array('color_type', '=', 'custom')
                ),
                'text' => array(
                    'type' => 'text',
                    'title' => esc_html__('Text', 'trucking'),
                    'description' => esc_html__('Button text.', 'trucking'),
                    'placeholder' => 'Button'
                ),
                'link' => array(
                    'type' => 'text',
                    'title' => esc_html__('Link', 'trucking'),
                    'description' => esc_html__('Button link.', 'trucking'),
                    'placeholder' => 'www.google.com'
                ),
                'target' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Target', 'trucking'),
                    'description' => esc_html__('Open URL in new window.', 'trucking')
                ),
                'position' => array(
                    'type' => 'select',
                    'title' => esc_html__('Position', 'trucking'),
                    'description' => esc_html__('Select button position', 'trucking'),
                    'options' => array(
                        'float-left' => 'Left',
                        'btn-centered' => 'Centered',
                        'float-right' => 'Right'
                    ),
                    'default' => 'float-right'
                ),
            );
        }

    }

}
?>
