<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists("CMA_Shortcodes_Google_Maps")) {

    class CMA_Shortcodes_Google_Maps extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Google Maps', 'trucking');
            $settings['description'] = esc_html__('Creates Google Map with location of your choice.', 'trucking');
            $settings['shortcode'] = 'cma_google_maps';
            $settings['nested'] = false;
            $settings['selected_option'] = 'type'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            $style = '';
            $custom_marker = '';
            $html = '';

            extract(shortcode_atts(array(
                'type' => 'roadmap',
                'latitude' => "40.74843",
                'longitude' => '-73.985655',
                'zoom' => '13',
                'ui' => '1',
                'scroll' => '1',
                'contrast' => 'default',
                'height' => '',
                'custom_market_position' => '0',
                'marker_latitude' => '40.74843',
                'marker_longitude' => '-73.985655',
                'api_key' => ''
                            ), (array) $atts, 'cma_google_maps'));
            
             // get API key
            $api_key = trim($api_key);            
            $maps_api_url = "https://maps.googleapis.com/maps/api/js?key=" . $api_key;
            
            /* Google Maps script */
            wp_enqueue_script( 'cma-scripts-googlemaps-api', $maps_api_url, array( 'jquery' ), '1.0', TRUE );            
            /* Script for Google Maps */
            wp_enqueue_script( 'cma-scripts-googlemaps', CMA_CONTENT_URL . 'gmaps/js/google-maps.js', array( 'jquery', 'cma-scripts-googlemaps-api' ), '1.0', TRUE );      

            if (!empty($height)) {
                $style = "style='height: {$height}px;'";
            }
            
            $marker_latitude = strip_tags($marker_latitude);
            $marker_longitude = strip_tags($marker_longitude);

            if ($custom_market_position == '1') {
                $custom_marker = " data-marker-lat='{$marker_latitude}' data-marker-long='{$marker_longitude}'";
            }

            $html .= "<div class='map-canvas' data-type='{$type}' data-long='{$longitude}' data-lat='{$latitude}' data-zoom='{$zoom}' data-default-ui='{$ui}' data-scroll-wheel='{$scroll}' data-contrast='{$contrast}' {$custom_marker} {$style}></div>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'type' => array(
                    'type' => 'radio',
                    'title' => esc_html__('Type', 'trucking'),
                    'description' => esc_html__('Select Map type.', 'trucking'),
                    'options' => array(
                        'roadmap' => 'Road Map',
                        'terrain' => 'Terrain',
                        'satellite' => 'Satellite'
                    ),
                    'default' => 'roadmap'
                ),
                'latitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Latitude', 'trucking'),
                    'description' => esc_html__('Location Latitude for map.', 'trucking'),
                    'placeholder' => '46.305746'
                ),
                'longitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Longitude', 'trucking'),
                    'description' => esc_html__('Location Longitude for map.', 'trucking'),
                    'placeholder' => '16.336607'
                ),
                'zoom' => array(
                    'type' => 'number',
                    'title' => esc_html__('Zoom', 'trucking'),
                    'description' => esc_html__('Zoom parameter.', 'trucking'),
                    'default' => '13'
                ),
                'ui' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('User Interface', 'trucking'),
                    'description' => esc_html__('User Interface disable/enable.', 'trucking'),
                    'default' => '1'
                ),
                'scroll' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Zoom scrolling', 'trucking'),
                    'description' => esc_html__('Disable zoom when scrolling over map.', 'trucking'),
                    'default' => '0'
                ),
                'contrast' => array(
                    'type' => 'select',
                    'title' => esc_html__('Contrast', 'trucking'),
                    'description' => esc_html__('Change map appearance.', 'trucking'),
                    'options' => array(
                        'default' => 'Default',
                        'saturated' => 'Saturated',
                        'grayscale' => 'Grayscale',
                    ),
                    'default' => 'default'
                ),
                'height' => array(
                    'type' => 'number',
                    'title' => esc_html__('Height', 'trucking'),
                    'description' => esc_html__('Enter custom map height (default 500px).', 'trucking'),
                    'placeholder' => '500'
                ),
                'custom_market_position' => array(
                    'type' => 'checkbox',
                    'title' => esc_html__('Custom marker position', 'trucking'),
                    'description' => esc_html__('Change default market position (center of the map).', 'trucking'),
                    'default' => '0'
                ),
                'marker_latitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Marker Latitude', 'trucking'),
                    'description' => esc_html__('Custom marker latitude.', 'trucking'),
                    'placeholder' => '46.305746',
                    'condition' => array('custom_market_position', '==', '1')
                ),
                'marker_longitude' => array(
                    'type' => 'text',
                    'title' => esc_html__('Marker Longitude', 'trucking'),
                    'description' => esc_html__('Custom marker longitude.', 'trucking'),
                    'placeholder' => '16.336607',
                    'condition' => array('custom_market_position', '==', '1')
                ),
                'api_key' => array(
                    'type' => 'text',
                    'title' => esc_html__('API key', 'trucking'),
                    'description' => esc_html__('Enter your Google Maps API key. Guide can be found in Documentation.', 'trucking'),
                    'placeholder' => '',
                ),
            );
        }

    }

}
?>