<?php

// Prevent loading file directly
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists("CMA_Shortcodes_Image_Grid")) {

    class CMA_Shortcodes_Image_Grid extends Content_Maker_Shortcodes {

        function shortcode_block_info() {
            $settings['title'] = esc_html__('Image Grid', 'trucking');
            $settings['description'] = esc_html__('Simple grid image images.', 'trucking');
            $settings['shortcode'] = 'cma_image_grid';
            $settings['nested'] = false;
            $settings['selected_option'] = 'items|text'; // enter field ID - show this field's value on element on grid - easier to find desired element

            $this->shortcode_settings = $settings;
        }

        function shortcode_html($atts = array(), $content = null) {
            global $vlc_is_retina;

            $bkg_color_style = '';

            extract(shortcode_atts(array(
                'image_width' => '165',
                'image_height' => '55',
                'items' => ''
                            ), $atts, 'cma_image_grid'));

            $html = "<ul class='clients-li clearfix'>";

            foreach ($items as $index => $item) {
                $bkg_color_style = '';
                $image_html = '';

                if (!empty($item['color'])) {
                    $bkg_color_style = "style='background-color: {$item['color']}'";
                }

                $image = explode(',', $item['image']);

                //get first image
                $image_url = wp_get_attachment_image_src($image[0], 'full');

                // crop the image
                $params = array('width' => $image_width, 'height' => $image_height);

                // filter image size, retina check is hooked on this
                $params = apply_filters('cma_element_image_dimensions', $params, $this->shortcode_settings['shortcode']);

                $cropped_image = bfi_thumb($image_url[0], $params);

                // wrap image in anchor tag if url is set
                if (!empty($item['url'])) {
                    $url = esc_url($item['url']);
                    $image_html = "<a href='{$url}'><img src='{$cropped_image}' alt='client'/></a>";
                } else {
                    $image_html = "<img src='{$cropped_image}' alt='client'/>";
                }

                $html .= "<li {$bkg_color_style}>                                
                             {$image_html}
                         </li>";
            }

            $html .= "</ul>";

            return $html;
        }

        function shortcode_options_fields() {

            $this->shortcode_options = array(
                'image_width' => array(
                    'type' => 'number',
                    'title' => esc_html__('Image width', 'trucking'),
                    'description' => esc_html__('Enter image width.', 'trucking'),
                    'default' => '165'
                ),
                'image_height' => array(
                    'type' => 'number',
                    'title' => esc_html__('Image height', 'trucking'),
                    'description' => esc_html__('Enter image height.', 'trucking'),
                    'default' => '55'
                ),
                'items' => array(
                    'type' => 'group',
                    'title' => 'Items',
                    'max' => '',
                    'options' => array(
                        'image' => array(
                            'type' => 'image',
                            'title' => esc_html__('Image', 'trucking'),
                            'description' => esc_html__('Upload carousel image.', 'trucking')
                        ),
                        'url' => array(
                            'type' => 'text',
                            'title' => esc_html__('URL', 'trucking'),
                            'description' => esc_html__('Enter image URL.', 'trucking')
                        ),
                        'color' => array(
                            'type' => 'color_picker',
                            'title' => esc_html__('Background color', 'trucking'),
                            'description' => esc_html__('Background color.', 'trucking'),
                            'default' => ''
                        ),
                    )
                ),
            );
        }

    }

}
?>
