<?php
/*
 * Title section for pages and posts.
 */

global $vlc_page_title, $volcanno_options, $vlc_is_retina, $volcanno_theme_config;
$title_classes = '';

// get page id
if (is_home() || is_singular('post') || is_category() || is_tag() || is_year() || is_month() || is_day() || is_author() || is_search() || is_404()) {
    if (!is_front_page()) {
        $page_id = ( 'page' == get_option('show_on_front') ? get_option('page_for_posts') : get_the_ID() );
    } else {
        $page_id = false;
    }
} else if (is_singular('pi_vehicles') || is_tax('vehicle-category')) {
    $page_id = true;
} else {
    $page_id = get_the_ID();
}

// defaults if Core plugin isn't activated
if (!RWMB_META_BOX || !$page_id) {

    // page title color or background image
    $page_title_color = '#ededed';
    $page_title_image = false;
} else {
    // title style
    if (is_singular('pi_vehicles') || is_tax('vehicle-category')) {

        // page title color or background image
        $page_title_color = $volcanno_options['vehicles_category_title_color'];
        $page_title_image = isset($volcanno_options['vehicles_category_title_image']) ? $volcanno_options['vehicles_category_title_image'] : '';
    } else if (is_singular('post') || is_category()) {

        // page title color or background image
        $page_title_color = $volcanno_options['blog_category_title_color'];
        $page_title_image = isset($volcanno_options['blog_category_title_image']) ? $volcanno_options['blog_category_title_image'] : '';
    } else {

        // page title color
        $page_title_color = rwmb_meta('pg_title_color', '', $page_id);
        if (empty($page_title_color))
            $page_title_color = '#ededed';

        // page title image
        $page_title_image = rwmb_meta('pg_title_image', 'type=image&size=full', $page_id);

        if (!empty($page_title_image))
            $page_title_image = reset($page_title_image);
    }
}

// get header style
$header_style = apply_filters('volcanno_header_style', $volcanno_options['header_style']);
if ($header_style == 'header-style01' || $header_style == 'header-style01-tp') {
    $style = "page-title-style01";
} else {
    $style = "page-title-style02";
}

if (!empty($page_title_image['url'])) {
    if ($style == 'page-title-style01') {
        $params = array('width' => 1920, 'height' => 333);
    } else {
        $params = array('width' => 1920, 'height' => 170);

        // if user is on retina device, double the size of image
        if ($vlc_is_retina) {
            $params = array('width' => 3840, 'height' => 340);
        }
    }

    $cropped_image = bfi_thumb($page_title_image['url'], $params);
    $page_title_style = "style='background-image: url(" . esc_url_raw($cropped_image) . ") !important;'";
} else if (!empty($page_title_color)) {
    $page_title_style = "style='background: " . esc_html($page_title_color) . " !important;'";
} else {
    $page_title_style = '';
}

// breadcrumbs
$show_breadrumbs = $volcanno_options['show_breadcrumbs'];
?>
<!-- .page-title start -->
<div class="<?php echo sanitize_html_class($style) ?> " <?php echo $page_title_style; ?>>
    <div class="pt-mask"></div>
    <div class="container">
        <div class="row">
            <?php if ($style == 'page-title-style01'): ?>
                <div class="col-md-12">
                    <h1><?php echo wp_kses($vlc_page_title, $volcanno_theme_config['allowed_html_tags']) ?></h1>
                    <div class="breadcrumb-container">
                        <?php
                        if ($show_breadrumbs == '1') {
                            volcanno_breadcrumbs();
                        }
                        ?>
                    </div>                
                </div><!-- .col-md-12 end -->
            <?php else: ?>
                <div class="col-md-<?php echo ($show_breadrumbs != '1') ? '12' : '6' ?>">
                    <h1><?php echo wp_kses($vlc_page_title, $volcanno_theme_config['allowed_html_tags']) ?></h1>
                </div><!-- .col-md-6 end -->
                <?php if ($show_breadrumbs == '1') { ?>
                    <div class="col-md-6">
                        <div class="breadcrumb-container">
                            <?php volcanno_breadcrumbs(); ?>
                        </div>                
                    </div><!-- .col-md-6 end -->
                <?php } ?>
            <?php endif; ?>
        </div><!-- .row end -->
    </div><!-- .container end -->
</div><!-- .page-title-style01.page-title-negative-top end -->
