<?php

/* -----------------------------------------------------------------------------------

  Plugin Name: Custom Post Types
  Plugin URI: http://www.pixel-industry.com
  Description: A plugin that registers custom post types.
  Version: 1.0
  Author: Pixel Industry
  Author URI: http://www.pixel-industry.com

  ----------------------------------------------------------------------------------- */

if (!defined('VCPT_PLUGIN_URL'))
    define('VCPT_PLUGIN_URL', plugin_dir_url(__FILE__));

if (!function_exists('vcpt_load_admin_styles')) {

    function vcpt_load_admin_styles() {
        $current_screen = get_current_screen();

        if ($current_screen->id == 'pi_portfolio' || $current_screen->id == 'pi_gallery' || $current_screen->id == 'page') {
            wp_enqueue_style('portfolio-formats', plugins_url('', __FILE__) . '/css/volcanno-custom-post-types.css', array(), '1.0', 'screen');
        }
    }

}

add_action('admin_enqueue_scripts', 'vcpt_load_admin_styles');

if (!function_exists('vcpt_cpt_config')) {

    function vcpt_cpt_config() {
        global $post_types_config;

// configuration
        $post_types_config = array(
            'pi_portfolio' => array(
                'cpt' => '0',
                'taxonomy' => '0'
            ),
            'pi_gallery' => array(
                'cpt' => '0',
                'taxonomy' => '0'
            ),
            'pi_vehicles' => array(
                'cpt' => '0',
                'taxonomy' => '0'
            )
        );

        $post_types_config = array_merge($post_types_config, apply_filters('vcpt_register_custom_post_types', $post_types_config));
    }

}
add_action('init', 'vcpt_cpt_config', 9);

/* Function that returns active Custom Post Types */
function vcpt_get_cpts(){
    global $post_types_config;
    
    return $post_types_config;
}


/* ------------------------------------------------------------------
 * Portfolio post type
  ------------------------------------------------------------------- */
if (!function_exists('vcpt_cpt_create_post_type_portfolio')) {

    function vcpt_cpt_create_post_type_portfolio() {
        global $post_types_config;

        if ($post_types_config['pi_portfolio']['cpt'] != '1')
            return;


        $labels = array(
            'name' => __('Portfolio', 'pi_framework'),
            'singular_name' => __('Portfolio', 'pi_framework'),
            'add_new' => _x('Add New', 'portfolio', 'pi_framework'),
            'add_new_item' => __('Add New Item', 'pi_framework'),
            'edit_item' => __('Edit Item', 'pi_framework'),
            'new_item' => __('New Item', 'pi_framework'),
            'view_item' => __('View Item', 'pi_framework'),
            'search_items' => __('Search Item', 'pi_framework'),
            'not_found' => __('No Portoflio images found', 'pi_framework'),
            'not_found_in_trash' => __('No portfolio images found in Trash', 'pi_framework'),
            'parent_item_colon' => ''
        );

        $args = array(
            'labels' => $labels,
            'public' => true,
            'exclude_from_search' => true,
            'publicly_queryable' => true,
            'rewrite' => array('slug' => 'portfolio-item', 'with_front' => true),
            'show_ui' => true,
            'query_var' => true,
            'capability_type' => 'post',
            'hierarchical' => false,
            'menu_position' => '20',
            'menu_icon' => VCPT_PLUGIN_URL . '/imgs/portfolio.png',
            'supports' => array('title', 'editor', 'thumbnail', 'custom-fields', 'excerpt', 'post-formats')
        );

        register_post_type('pi_portfolio', $args);
    }

}
add_action('init', 'vcpt_cpt_create_post_type_portfolio');

/* Create taxonomy Portfolio Category */
if (!function_exists('vcpt_cpt_create_portfolio_taxonomies')) {

    function vcpt_cpt_create_portfolio_taxonomies() {
        global $post_types_config;

        if ($post_types_config['pi_portfolio']['cpt'] != '1' && $post_types_config['pi_portfolio']['taxonomy'] != '1')
            return;

        register_taxonomy("portfolio-category", array("pi_portfolio"), array("hierarchical" => true, "label" => __("Categories", 'pi_framework'), "singular_label" => __("Portfolio Category", 'pi_framework'), "rewrite" => array('slug' => 'portfolio-category', 'hierarchical' => true)));
        if (!term_exists('default', 'portfolio-category')) {
            $parent_term = term_exists('default', 'portfolio-category'); // array is returned if taxonomy is given
            $parent_term_id = $parent_term['term_id']; // get numeric term id
            wp_insert_term(
                    __('Default', 'pi_framework'), // the term 
                    'portfolio-category', // the taxonomy
                    array(
                'description' => __('Default portfolio category.', 'pi_framework'),
                'slug' => 'default',
                'parent' => $parent_term_id
                    )
            );
        }
    }

}
add_action('init', 'vcpt_cpt_create_portfolio_taxonomies');

/* Set default portfolio category when publishing portfolio post */
if (!function_exists('vcpt_cpt_set_default_object_terms')) {

    function vcpt_cpt_set_default_object_terms($post_id, $post) {
        global $post_types_config;

        if ($post_types_config['pi_portfolio']['cpt'] != '1' && $post_types_config['pi_portfolio']['taxonomy'] != '1')
            return;

        if ($post->post_status === 'publish' && $post->post_type == "pi_portfolio") {
            $defaults = array(
                'portfolio-category' => array('default')
            );
            $taxonomies = get_object_taxonomies($post->post_type);
            foreach ((array) $taxonomies as $taxonomy) {
                $terms = wp_get_post_terms($post_id, $taxonomy);
                if (empty($terms) && array_key_exists($taxonomy, $defaults)) {
                    wp_set_object_terms($post_id, $defaults[$taxonomy], $taxonomy);
                }
            }
        }
    }

}
add_action('save_post', 'vcpt_cpt_set_default_object_terms', 100, 2);

/* Show Portfolio image in list of Portfolios */
if (!function_exists('vcpt_cpt_columns_head_only_pi_portfolio')) {

// Create new column
    function vcpt_cpt_columns_head_only_pi_portfolio($defaults) {
        global $post_types_config;

        if ($post_types_config['pi_portfolio']['cpt'] != '1')
            return;

        $defaults['portfolio_image'] = 'Image';

        return $defaults;
    }

}

if (!function_exists('vcpt_cpt_columns_content_only_pi_portfolio')) {

// show image in column
    function vcpt_cpt_columns_content_only_pi_portfolio($column_name, $post_ID) {
        global $post_types_config;

        if ($post_types_config['pi_portfolio']['cpt'] != '1')
            return;

        if ($column_name == 'portfolio_image') {
            $images = get_post_custom_values('pf_image', $post_ID);
            $image_url = wp_get_attachment_image_src($images[0], 'full');
            $params = array("width" => 150, "height" => 120);
            $featured_image = bfi_thumb($image_url[0], $params);

            if ($featured_image) {
                // image found
                echo '<img src="' . $featured_image . '" alt="Image"/>';
            } else {
                // no image
                $default_image = VCPT_PLUGIN_URL . '/imgs/placeholder.jpg';
                echo "<img src='{$default_image}' width='150' alt='placeholder image'/>";
            }
        }
    }

}
// Portfolio post type filter
add_filter('manage_pi_portfolio_posts_columns', 'vcpt_cpt_columns_head_only_pi_portfolio', 10);
add_action('manage_pi_portfolio_posts_custom_column', 'vcpt_cpt_columns_content_only_pi_portfolio', 10, 2);

/* ------------------------------------------------------------------
 * Gallery post type
  ------------------------------------------------------------------- */
if (!function_exists('vcpt_cpt_create_post_type_gallery')) {

    function vcpt_cpt_create_post_type_gallery() {
        global $post_types_config;

        if ($post_types_config['pi_gallery']['cpt'] != '1')
            return;

        $labels = array(
            'name' => __('Gallery', 'pi_framework'),
            'singular_name' => __('Gallery', 'pi_framework'),
            'add_new' => _x('Add New', 'gallery', 'pi_framework'),
            'add_new_item' => __('Add New Item', 'pi_framework'),
            'edit_item' => __('Edit Item', 'pi_framework'),
            'new_item' => __('New Item', 'pi_framework'),
            'view_item' => __('View Item', 'pi_framework'),
            'search_items' => __('Search Item', 'pi_framework'),
            'not_found' => __('No Galleries images found', 'pi_framework'),
            'not_found_in_trash' => __('No galleries found in Trash', 'pi_framework'),
            'parent_item_colon' => ''
        );

        $args = array(
            'labels' => $labels,
            'public' => true,
            'exclude_from_search' => true,
            'publicly_queryable' => true,
            'rewrite' => array('slug' => 'gallery-item', 'with_front' => true),
            'show_ui' => true,
            'query_var' => true,
            'capability_type' => 'post',
            'hierarchical' => false,
            'menu_position' => '20',
            'menu_icon' => VCPT_PLUGIN_URL . '/imgs/portfolio.png',
            'supports' => array('title', 'editor', 'thumbnail', 'custom-fields', 'excerpt', 'post-formats')
        );

        register_post_type('pi_gallery', $args);
    }

}
add_action('init', 'vcpt_cpt_create_post_type_gallery');

/* Create taxonomy Portfolio Category */
if (!function_exists('vcpt_cpt_create_gallery_taxonomies')) {

    function vcpt_cpt_create_gallery_taxonomies() {
        global $post_types_config;

        if ($post_types_config['pi_gallery']['cpt'] != '1' && $post_types_config['pi_gallery']['taxonomy'] != '1')
            return;

        register_taxonomy("gallery-category", array("pi_gallery"), array("hierarchical" => true, "label" => __("Categories", 'pi_framework'), "singular_label" => __("Gallery Category", 'pi_framework'), "rewrite" => array('slug' => 'gallery-category', 'hierarchical' => true)));
        if (!term_exists('default', 'gallery-category')) {
            $parent_term = term_exists('default', 'gallery-category'); // array is returned if taxonomy is given
            $parent_term_id = $parent_term['term_id']; // get numeric term id
            wp_insert_term(
                    __('Default', 'pi_framework'), // the term 
                    'gallery-category', // the taxonomy
                    array(
                'description' => __('Default gallery category.', 'pi_framework'),
                'slug' => 'default',
                'parent' => $parent_term_id
                    )
            );
        }
    }

}
add_action('init', 'vcpt_cpt_create_gallery_taxonomies');

/* Set default portfolio category when publishing portfolio post */
if (!function_exists('vcpt_cpt_gallery_set_default_object_terms')) {

    function vcpt_cpt_gallery_set_default_object_terms($post_id, $post) {
        global $post_types_config;

        if ($post_types_config['pi_gallery']['cpt'] != '1' && $post_types_config['pi_gallery']['taxonomy'] != '1')
            return;

        if ($post->post_status === 'publish' && $post->post_type == "pi_gallery") {
            $defaults = array(
                'gallery-category' => array('default')
            );
            $taxonomies = get_object_taxonomies($post->post_type);
            foreach ((array) $taxonomies as $taxonomy) {
                $terms = wp_get_post_terms($post_id, $taxonomy);
                if (empty($terms) && array_key_exists($taxonomy, $defaults)) {
                    wp_set_object_terms($post_id, $defaults[$taxonomy], $taxonomy);
                }
            }
        }
    }

}
add_action('save_post', 'vcpt_cpt_gallery_set_default_object_terms', 100, 2);

/* Show Portfolio image in list of Portfolios */
if (!function_exists('vcpt_cpt_columns_head_only_pi_gallery')) {

// Create new column
    function vcpt_cpt_columns_head_only_pi_gallery($defaults) {
        global $post_types_config;

        if ($post_types_config['pi_gallery']['cpt'] != '1')
            return;

        $defaults['gallery_image'] = 'Image';
        return $defaults;
    }

}

if (!function_exists('vcpt_cpt_columns_content_only_pi_gallery')) {

// show image in column
    function vcpt_cpt_columns_content_only_pi_gallery($column_name, $post_ID) {
        global $post_types_config;

        if ($post_types_config['pi_gallery']['cpt'] != '1')
            return;

        if ($column_name == 'gallery_image') {
            $images = get_post_custom_values('pf_image', $post_ID);
            $image_url = wp_get_attachment_image_src($images[0], 'full');
            $params = array("width" => 150, "height" => 120);
            $featured_image = bfi_thumb($image_url[0], $params);

            if ($featured_image) {
                // image found
                echo '<img src="' . $featured_image . '" alt="Image"/>';
            } else {
                // no image
                $default_image = VCPT_PLUGIN_URL . '/imgs/placeholder.jpg';
                echo "<img src='{$default_image}' width='150' alt='placeholder image'/>";
            }
        }
    }

}
// Portfolio post type filter
add_filter('manage_pi_gallery_posts_columns', 'vcpt_cpt_columns_head_only_pi_gallery', 10);
add_action('manage_pi_gallery_posts_custom_column', 'vcpt_cpt_columns_content_only_pi_gallery', 10, 2);


/* ------------------------------------------------------------------
 * Vehicle post type
  ------------------------------------------------------------------- */
if (!function_exists('vcpt_cpt_create_post_type_vehicles')) {

    function vcpt_cpt_create_post_type_vehicles() {
        global $post_types_config;

        if ($post_types_config['pi_vehicles']['cpt'] != '1')
            return;


        $labels = array(
            'name' => __('Vehicles', 'pi_framework'),
            'singular_name' => __('Vehicles', 'pi_framework'),
            'add_new' => _x('Add New', 'vehicle', 'pi_framework'),
            'add_new_item' => __('Add New Item', 'pi_framework'),
            'edit_item' => __('Edit Item', 'pi_framework'),
            'new_item' => __('New Item', 'pi_framework'),
            'view_item' => __('View Item', 'pi_framework'),
            'search_items' => __('Search Item', 'pi_framework'),
            'not_found' => __('No Vehicles found.', 'pi_framework'),
            'not_found_in_trash' => __('No vehicles found in Trash', 'pi_framework'),
            'parent_item_colon' => ''
        );

        $args = array(
            'labels' => $labels,
            'public' => true,
            'exclude_from_search' => true,
            'publicly_queryable' => true,
            'rewrite' => array('slug' => 'vehicle-fleet', 'with_front' => true),
            'show_ui' => true,
            'query_var' => true,
            'capability_type' => 'post',
            'hierarchical' => false,
            'menu_position' => '20',
            'menu_icon' => VCPT_PLUGIN_URL . '/imgs/truck.png',
            'supports' => array('title', 'editor', 'thumbnail', 'custom-fields', 'excerpt', 'post-formats')
        );

        register_post_type('pi_vehicles', $args);
    }

}
add_action('init', 'vcpt_cpt_create_post_type_vehicles');

/* Create taxonomy Vehicle Category */
if (!function_exists('vcpt_cpt_create_vehicle_taxonomies')) {

    function vcpt_cpt_create_vehicle_taxonomies() {
        global $post_types_config;

        if ($post_types_config['pi_vehicles']['cpt'] != '1' && $post_types_config['pi_vehicles']['taxonomy'] != '1')
            return;

        register_taxonomy("vehicle-category", array("pi_vehicles"), array("hierarchical" => true, "label" => __("Categories", 'pi_framework'), "singular_label" => __("Vehicles Category", 'pi_framework'), "rewrite" => array('slug' => 'vehicles-category', 'hierarchical' => true)));
        if (!term_exists('default', 'vehicle-category')) {
            $parent_term = term_exists('default', 'vehicle-category'); // array is returned if taxonomy is given
            $parent_term_id = $parent_term['term_id']; // get numeric term id
            wp_insert_term(
                    __('Default', 'pi_framework'), // the term 
                    'vehicle-category', // the taxonomy
                    array(
                'description' => __('Default vehicle category.', 'pi_framework'),
                'slug' => 'default',
                'parent' => $parent_term_id
                    )
            );
        }
    }

}
add_action('init', 'vcpt_cpt_create_vehicle_taxonomies');

/* Set default vehicle category when publishing vehicles post */
if (!function_exists('vcpt_cpt_vehicles_set_default_object_terms')) {

    function vcpt_cpt_vehicles_set_default_object_terms($post_id, $post) {
        global $post_types_config;

        if ($post_types_config['pi_vehicles']['cpt'] != '1' && $post_types_config['pi_vehicles']['taxonomy'] != '1')
            return;

        if ($post->post_status === 'publish' && $post->post_type == "pi_vehicles") {
            $defaults = array(
                'vehicle-category' => array('default')
            );
            $taxonomies = get_object_taxonomies($post->post_type);
            foreach ((array) $taxonomies as $taxonomy) {
                $terms = wp_get_post_terms($post_id, $taxonomy);
                if (empty($terms) && array_key_exists($taxonomy, $defaults)) {
                    wp_set_object_terms($post_id, $defaults[$taxonomy], $taxonomy);
                }
            }
        }
    }

}
add_action('save_post', 'vcpt_cpt_vehicles_set_default_object_terms', 100, 2);

/* Show vehicle image in list of Vehicles */
if (!function_exists('vcpt_cpt_columns_head_only_pi_vehicles')) {

// Create new column
    function vcpt_cpt_columns_head_only_pi_vehicles($defaults) {
        global $post_types_config;

        if ($post_types_config['pi_vehicles']['cpt'] != '1')
            return;

        $defaults['vehicle_image'] = 'Image';

        return $defaults;
    }

}

if (!function_exists('vcpt_cpt_columns_content_only_pi_vehicles')) {

// show image in column
    function vcpt_cpt_columns_content_only_pi_vehicles($column_name, $post_ID) {
        global $post_types_config;

        if ($post_types_config['pi_vehicles']['cpt'] != '1')
            return;

        if ($column_name == 'vehicle_image') {
            $images = get_post_custom_values('vh_image', $post_ID);
            $image_url = wp_get_attachment_image_src($images[0], 'full');
            $params = array("width" => 150, "height" => 120);
            $featured_image = bfi_thumb($image_url[0], $params);

            if ($featured_image) {
                // image found
                echo '<img src="' . $featured_image . '" alt="Image"/>';
            } else {
                // no image
                $default_image = VCPT_PLUGIN_URL . '/imgs/placeholder.jpg';
                echo "<img src='{$default_image}' width='150' alt='placeholder image'/>";
            }
        }
    }

}
// Vehicles post type filter
add_filter('manage_pi_vehicles_posts_columns', 'vcpt_cpt_columns_head_only_pi_vehicles', 10);
add_action('manage_pi_vehicles_posts_custom_column', 'vcpt_cpt_columns_content_only_pi_vehicles', 10, 2);
?>
